@@ -20,6 +20,8 @@ sub write_out {
     $text .= "iptables -N CIF_OUT\n";
     $text .= "iptables -F CIF_OUT\n";
 
+    my $isWhitelist = 0;
+
     foreach (@$array){
         my $address = $_->{'address'};
         unless($_->{'address'} =~ /^$RE{'net'}{'IPv4'}/){
@@ -27,13 +29,29 @@ sub write_out {
             return '';
         }
         $_->{'address'} = normalize_address($_->{'address'});
-        $text .= "iptables -A CIF_IN -s $_->{'address'} -j DROP\n";
-        $text .= "iptables -A CIF_OUT -d $_->{'address'} -j DROP\n";
+        if($_->{'assessment'} eq 'whitelist'){
+            $isWhitelist = 1;
+            $text .= "iptables -A CIF_IN -s $_->{'address'} -j ACCEPT\n";
+            $text .= "iptables -A CIF_OUT -d $_->{'address'} -j ACCEPT\n";
+        } else {
+            $text .= "iptables -A CIF_IN -s $_->{'address'} -j DROP\n";
+            $text .= "iptables -A CIF_OUT -d $_->{'address'} -j DROP\n";
+        }
     }
     $text .= "iptables -A INPUT -j CIF_IN\n";
-    $text .= "iptables -A CIF_IN -j LOG --log-level 6 --log-prefix '[IPTABLES] cif dropped'\n";
+    
+    if($isWhitelist){
+        $text .= "iptables -A CIF_IN -j LOG --log-level 6 --log-prefix '[IPTABLES] cif accepted'\n";
+    } else {
+        $text .= "iptables -A CIF_IN -j LOG --log-level 6 --log-prefix '[IPTABLES] cif dropped'\n";
+    }
+    
     $text .= "iptables -A OUTPUT -j CIF_OUT\n";
-    $text .= "iptables -A CIF_OUT -j LOG --log-level 6 --log-prefix '[IPTABLES cif dropped'\n";
+    if($isWhitelist){
+        $text .= "iptables -A CIF_OUT -j LOG --log-level 6 --log-prefix '[IPTABLES] cif accepted'\n";
+    } else {
+        $text .= "iptables -A CIF_OUT -j LOG --log-level 6 --log-prefix '[IPTABLES] cif dropped'\n";
+    }
     return $text;
 }
 
@@ -42,7 +60,7 @@ sub normalize_address {
 
     my @bits = split(/\./,$addr);
     foreach(@bits){
-        next unless(/^0{1,2}/);
+        next unless(/^0{1,2}[1-9]{1,2}/);
         $_ =~ s/^0{1,2}//;
     }
     return join('.',@bits);
